export interface PactV3Options {
    dir: string;
    consumer: string;
    provider: string;
}
export interface V3ProviderState {
    description: string;
    parameters?: any;
}
export interface V3Request {
    method: string;
    path: string;
    query?: {
        [param: string]: string;
    };
    headers?: {
        [header: string]: string;
    };
    body?: any;
}
export interface V3Response {
    status: number;
    headers?: {
        [header: string]: string;
    };
    body?: any;
}
export interface V3MockServer {
    port: number;
    url: string;
    id: string;
}
export declare class PactV3 {
    private opts;
    private states;
    private pact;
    constructor(opts: PactV3Options & {});
    given(providerState: string, parameters?: any): this;
    uponReceiving(desc: string): this;
    withRequest(req: V3Request): this;
    withRequestBinaryFile(req: V3Request, contentType: string, file: string): this;
    withRequestMultipartFileUpload(req: V3Request, contentType: string, file: string, part: string): this;
    willRespondWith(res: V3Response): this;
    withResponseBinaryFile(res: V3Response, contentType: string, file: string): this;
    withResponseMultipartFileUpload(req: V3Response, contentType: string, file: string, part: string): this;
    executeTest<T>(testFn: (mockServer: V3MockServer) => Promise<T>): Promise<T>;
}
